#
# spec file for package ocaml-sedlex
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with ocaml_sedlex_testsuite
%define build_flavor %nil
%if "%build_flavor" == "testsuite"
%if %{without ocaml_sedlex_testsuite}
ExclusiveArch:  do-not-build
%else
ExclusiveArch:  aarch64 ppc64 ppc64le riscv64 s390x x86_64
%endif
%define nsuffix -testsuite
%else
%define nsuffix %nil
ExclusiveArch:  aarch64 ppc64 ppc64le riscv64 s390x x86_64
%endif

%define     pkg ocaml-sedlex
Name:           %pkg%nsuffix
Version:        3.3
Release:        1.2
%{?ocaml_preserve_bytecode}
Summary:        Unicode-friendly lexer generator
License:        MIT
Group:          Development/Languages/OCaml
URL:            https://opam.ocaml.org/packages/sedlex
Source0:        %pkg-%version.tar.xz
BuildRequires:  ocaml(ocaml_base_version) >= 4.08
BuildRequires:  ocaml-dune >= 3.0
BuildRequires:  ocaml-rpm-macros >= 20240909
BuildRequires:  ocamlfind(gen)
BuildRequires:  ocamlfind(ppxlib)

%if "%build_flavor" == "testsuite"
BuildRequires:  ocamlfind(ppx_expect)
BuildRequires:  ocamlfind(sedlex)
%endif

%description
A lexer generator for OCaml, similar to ocamllex, but supporting Unicode.
Contrary to ocamllex, lexer specifications for sedlex are embedded in
regular OCaml source files.


%package        devel
Summary:        Development files for %name
Group:          Development/Languages/OCaml
Requires:       %name = %version

%description    devel
The %name-devel package contains libraries and signature files for
developing applications that use %name.

%prep
%autosetup -p1 -n %pkg-%version

%build
dune_release_pkgs='sedlex'
%ocaml_dune_setup
%if "%build_flavor" == ""
%ocaml_dune_build
%endif

%install
%if "%build_flavor" == ""
%ocaml_dune_install
%ocaml_create_file_list
%endif

%if "%build_flavor" == "testsuite"
%check
%ocaml_dune_test
%endif

%if "%build_flavor" == ""
%files -f %name.files
%doc README.md

%files devel -f %name.files.devel

%endif

%changelog
* Mon Mar  3 2025 ohering@suse.de
- Update to version 3.3
  see included CHANGES.md file for details
* Fri Jul  7 2023 ohering@suse.de
- Update to version 3.2
  see included CHANGES.md for details
* Sun May 21 2023 ohering@suse.de
- JaneStreet libraries are 64bit, this pkg depends on them (v2)
* Fri May  5 2023 ohering@suse.de
- JaneStreet libraries are 64bit, this pkg depends on them
* Fri Mar  3 2023 ohering@suse.de
- Update to version 3.1
  Update unicode version to 15.0.0
* Sun Jan  1 2023 ohering@suse.de
- Update to version 3.0
  Handle newer ppxlib API
* Mon Dec  6 2021 ohering@suse.de
- Update to version 2.5
  Update unicode version to 14.0.0
* Sat Sep 11 2021 ohering@suse.de
- Update to version 2.4
  Update unicode version to 13.0.0
* Thu Jan 21 2021 ohering@suse.de
- Update to version 2.3
  Switch to ppxlib
* Thu Aug 20 2020 ohering@suse.de
- Update to version 2.2
  Support for OCaml 4.08
* Fri Nov  1 2019 ohering@suse.de
- Require current dune macros
- Use _service file
- Remove unicode-data.diff and dependency to unicode-ucd due to
  usage of dune release profile
* Tue Oct 29 2019 Andy Li <andy@onthewings.net>
- New upstream version.
  + Auto-generate unicode data.
  + Switch to dune for building.
  + Switch from int codepoints to Uchar.t codepoints.
  + Track lexing position.
- Remove ppx_tools_versioned-521.patch.
- Add unicode-data.diff to use unicode data files from unicode-ucd.
* Fri Feb  8 2019 andy@onthewings.net
- Remove make parallel build.
* Fri Dec 21 2018 andy@onthewings.net
- Add ppx_tools_versioned-521.patch that fixes compatibility with
  ppx_tools_versioned 5.2.1.
* Wed Jun 13 2018 andy@onthewings.net
- Initial packaging.
